@@ -266,7 +266,7 @@ my %SEARCH_RESULT_ITEM_XLATE = (
     id => "id",
     title => "title",
     subtitle => "subtitle",
-    description => "description",
+    shortDescription => "description",
     mediaType => "media",
     downloadUrl => "url",
     encryptionKey => "encryption_key",
@@ -364,7 +364,8 @@ sub facet_search {
 
 sub item_metadata {
     my $self = shift;
-    return $self->_item_xlate( $self->native_item(@_) );
+    my $ni = $self->native_item(@_) or return;
+    return $self->_item_xlate( $ni->{item} );
 }
 
 =head1 CIRCULATION METHOD SPECIFICS
